==> haskell-microlens-platform-0.4.4.1-65.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-microlens-platform.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 microlens-platform
version:              0.4.4.1
visibility:           public
id:                   microlens-platform-0.4.4.1-u1Ge9ecx9XEkFvvdmzgM2
key:                  microlens-platform-0.4.4.1-u1Ge9ecx9XEkFvvdmzgM2
license:              BSD-3-Clause
maintainer:           Steven Fontanella <steven.fontanella@gmail.com>
author:               Edward Kmett, Artyom Kazak
homepage:             http://github.com/stevenfontanella/microlens
synopsis:             microlens + all batteries included (best for apps)
description:
    This package exports a module which is the recommended starting point for using <http://hackage.haskell.org/package/microlens microlens> if you aren'\''t trying to keep your dependencies minimal. By importing @Lens.Micro.Platform@ you get all functions and instances from <http://hackage.haskell.org/package/microlens microlens>, <http://hackage.haskell.org/package/microlens-th microlens-th>, <http://hackage.haskell.org/package/microlens-mtl microlens-mtl>, <http://hackage.haskell.org/package/microlens-ghc microlens-ghc>, as well as instances for @Vector@, @Text@, and @HashMap@.

    The minor and major versions of microlens-platform are incremented whenever the minor and major versions of any other microlens package are incremented, so you can depend on the exact version of microlens-platform without specifying the version of microlens (microlens-mtl, etc) you need.

    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/stevenfontanella/microlens#readme on Github>.

category:             Data, Lenses
abi:                  a5125d86ae5be716fe7464eaa8a31bce
exposed:              True
exposed-modules:      Lens.Micro.Platform Lens.Micro.Platform.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/microlens-platform-0.4.4.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/microlens-platform-0.4.4.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/microlens-platform-0.4.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microlens-platform
hs-libraries:         HSmicrolens-platform-0.4.4.1-u1Ge9ecx9XEkFvvdmzgM2
depends:
    base-4.18.2.1 hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-ghc-0.4.15.1-IAH2ejAowXtJjYrGb5ebmG
    microlens-mtl-0.2.1.0-Ewo8HmKpWhTASatFX3KZGS
    microlens-th-0.4.3.17-IPbJLKFzpBF3M0tXA6bBdw text-2.0.2
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:
    /usr/share/doc/haskell-microlens-platform/html/microlens-platform.haddock

haddock-html:         /usr/share/doc/haskell-microlens-platform/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microlens-platform-0.4.4.1-66-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-microlens-platform.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 microlens-platform
version:              0.4.4.1
visibility:           public
id:                   microlens-platform-0.4.4.1-7ZfpKpjp016gibCxCbEpP
key:                  microlens-platform-0.4.4.1-7ZfpKpjp016gibCxCbEpP
license:              BSD-3-Clause
maintainer:           Steven Fontanella <steven.fontanella@gmail.com>
author:               Edward Kmett, Artyom Kazak
homepage:             http://github.com/stevenfontanella/microlens
synopsis:             microlens + all batteries included (best for apps)
description:
    This package exports a module which is the recommended starting point for using <http://hackage.haskell.org/package/microlens microlens> if you aren'\''t trying to keep your dependencies minimal. By importing @Lens.Micro.Platform@ you get all functions and instances from <http://hackage.haskell.org/package/microlens microlens>, <http://hackage.haskell.org/package/microlens-th microlens-th>, <http://hackage.haskell.org/package/microlens-mtl microlens-mtl>, <http://hackage.haskell.org/package/microlens-ghc microlens-ghc>, as well as instances for @Vector@, @Text@, and @HashMap@.

    The minor and major versions of microlens-platform are incremented whenever the minor and major versions of any other microlens package are incremented, so you can depend on the exact version of microlens-platform without specifying the version of microlens (microlens-mtl, etc) you need.

    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/stevenfontanella/microlens#readme on Github>.

category:             Data, Lenses
abi:                  67e6ed37f7c79179bd940346db12d724
exposed:              True
exposed-modules:      Lens.Micro.Platform Lens.Micro.Platform.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/microlens-platform-0.4.4.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/microlens-platform-0.4.4.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/microlens-platform-0.4.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microlens-platform
hs-libraries:         HSmicrolens-platform-0.4.4.1-7ZfpKpjp016gibCxCbEpP
depends:
    base-4.18.2.1 hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-ghc-0.4.15.1-IAH2ejAowXtJjYrGb5ebmG
    microlens-mtl-0.2.1.0-Ewo8HmKpWhTASatFX3KZGS
    microlens-th-0.4.3.17-IPbJLKFzpBF3M0tXA6bBdw text-2.0.2
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:
    /usr/share/doc/haskell-microlens-platform/html/microlens-platform.haddock

haddock-html:         /usr/share/doc/haskell-microlens-platform/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
